cmoncrawl.middleware.synchronized
=================================

.. automodule:: cmoncrawl.middleware.synchronized

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      extract
      query_and_extract
   
   

   
   
   

   
   
   



